ReadConnection

Struct ReadConnection 

pub struct ReadConnection<D: Database>(/* private fields */);
A request guard which retrieves a single connection to a Database using the read_url.

For a database type of Db, a request guard of ReadConnection<Db> retrieves a single connection to Db.

Implementations

Source

impl<D: Database> ReadConnection<D>

pub fn into_inner(self) -> <D::Pool as Pool>::Connection

Gets the internal connection value